@@ -19,9 +19,7 @@ class ServiceEnum:
     SMART_FEEDS_ING = 'smart_feeds_ingestions'
     SMART_FEEDS_PROC = 'smart_feeds_processings'
     SMART_FEEDS_EXP = 'smart_feeds_export'
-    SMART_FEEDS_OMS = 'smart_feeds_order_management_system'
     SMART_FEEDS_PF = 'smart_feeds_product_flow'
-    SMART_ACTIVATION_CLUSTERING = 'smart_activation_clustering'
     TRACKING = 'adscale_user_activity_tracker'
     USERS = 'users'
     USERS_RIGHTS = 'users_rights'
